Changelog
=========


Version 0.1.2
-------------

Released on 2021-10-30.

Bug fixes:

* `#9 <https://github.com/CourtBouillon/pydyf/pull/9>`_:
  Implement escaping for Strings

Contributors:

* Guillaume Ayoub
* Rian McGuire

Backers and sponsors:

* Grip Angebotssoftware
* SimonSoft
* Menutech
* Manuel Barkhau
* Simon Sapin
* KontextWork
* René Fritz
* Maykin Media
* NCC Group
* Crisp BV
* Des images et des mots
* Andreas Zettl
* Nathalie Gutton
* Tom Pohl
* Moritz Mahringer
* Florian Demmer
* Yanal-Yvez Fargialla
* G. Allard
* Gábor


Version 0.1.1
-------------

Released on 2021-08-22.

Bug fixes:

* `0f7c8e9 <https://github.com/CourtBouillon/pydyf/commit/0f7c8e9>`_:
  Fix string encoding

Contributors:

* Guillaume Ayoub

Backers and sponsors:

* Grip Angebotssoftware
* PDF Blocks
* SimonSoft
* Menutech
* Manuel Barkhau
* Simon Sapin
* KontextWork
* René Fritz
* Maykin Media
* NCC Group
* Des images et des mots
* Andreas Zettl
* Nathalie Gutton
* Tom Pohl
* Moritz Mahringer
* Florian Demmer
* Yanal-Yvez Fargialla


Version 0.1.0
-------------

Released on 2021-08-21.

Bug fixes:

* `#8 <https://github.com/CourtBouillon/pydyf/issues/8>`_:
  Don’t use sys.stdout.buffer as default write object

Contributors:

* Guillaume Ayoub

Backers and sponsors:

* Grip Angebotssoftware
* PDF Blocks
* SimonSoft
* Menutech
* Manuel Barkhau
* Simon Sapin
* KontextWork
* René Fritz
* Maykin Media
* NCC Group
* Des images et des mots
* Andreas Zettl
* Nathalie Gutton
* Tom Pohl
* Moritz Mahringer
* Florian Demmer
* Yanal-Yvez Fargialla


Version 0.0.3
-------------

Released on 2021-04-22.

New features:

* Support text rendering

Contributors:

* Guillaume Ayoub

Backers and sponsors:

* PDF Blocks
* SimonSoft
* Menutech
* Simon Sapin
* Manuel Barkhau
* Andreas Zettl
* Nathalie Gutton
* Tom Pohl
* René Fritz
* Moritz Mahringer
* Florian Demmer
* KontextWork
* Michele Mostarda


Version 0.0.2
-------------

Released on 2021-03-13.

New features:

* Support linecap style
* Support line join et miter limit
* Add more cubic Bézier curve options

Bug fixes:

* Don’t include EOL in dictionary length
* Add a second binary line in PDF

Contributors:

* Guillaume Ayoub
* Lucie Anglade
* Alexander Schrijver
* Kees Cook

Backers and sponsors:

* PDF Blocks
* SimonSoft
* Menutech
* Simon Sapin
* Manuel Barkhau
* Andreas Zettl
* Nathalie Gutton
* Tom Pohl
* René Fritz
* Moritz Mahringer
* Florian Demmer
* KontextWork
* Michele Mostarda


Version 0.0.1
-------------

Released on 2020-12-06.

Initial release.

Contributors:

* Guillaume Ayoub
* Lucie Anglade

Backers and sponsors:

* PDF Blocks
* SimonSoft
* Menutech
* Simon Sapin
* Nathalie Gutton
* Andreas Zetti
* Tom Pohl
* Florian Demmer
* Moritz Mahringer
